@@ -7,7 +7,7 @@ import typing as t
 
 __title__       = "pyke"
 __author__      = "frissyn"
-__version__     = "0.0.1"
+__version__     = "0.0.3"
 __license__     = "MIT"
 __package__     = "pyke"
 __description__ = "Make-like build tool for Python."
@@ -15,7 +15,12 @@ __description__ = "Make-like build tool for Python."
 tasks: t.Mapping = {}
 
 from .task import task
+from .task import get_task
 from .task import exec_task
+from .task import default_task
 
 from .core import run
-from .core import runner
\ No newline at end of file
+from .core import shell
+from .core import export
+
+from .runner import runner
\ No newline at end of file
